@@ -68,4 +68,4 @@ class NestedPhysicalVolumeSerializer(WritableNestedSerializer):
 
     class Meta:
         model = PhysicalVolume
-        fields = ["id", "url", "display", "partition"]
+        fields = ["id", "url", "display", "pv_name"]
