@@ -22,30 +22,24 @@ from virtualization.models import Cluster, ClusterType, VirtualMachine
 class DriveForm(NetBoxModelForm):
     """Form for creating a new Drive object."""
     size = IntegerField(
-        required=True,
         label="Size (GB)",
         help_text="The size of the drive e.g. 25",
         validators=[MinValueValidator(1)],
     )
     cluster = DynamicModelChoiceField(
-        queryset=Cluster.objects.filter(
-            type__pk=ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
+        queryset=Cluster.objects.all(
+            # type__pk=ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
         ),
-        query_params={
-            'site_id': '$site',
-            'group_id': '$cluster_group',
-        },
         help_text="The Storage Cluster of the drive",
     )
     virtual_machine = DynamicModelChoiceField(
         queryset=VirtualMachine.objects.all(),
-        required=False,
         help_text="Mapping between drive and virtual machine  e.g. vm-testinstall-01",
     )
     description = CharField(
         required=False,
         label="Description",
-        help_text="Short Description e.g. Drive 1 on SSD Cluster",
+        help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
     )
 
     class Meta:
@@ -69,8 +63,8 @@ class DriveFilterForm(NetBoxModelFilterSetForm):
         label="Size (GB)",
     )
     cluster = DynamicModelChoiceField(
-        queryset=Cluster.objects.filter(
-            type__pk=ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
+        queryset=Cluster.objects.all(
+            # type__pk=ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
         ),
         required=False,
     )
