@@ -105,6 +105,9 @@ class PhysicalVolume(NetBoxModel):
         on_delete=models.CASCADE,
         related_name='partition_physicalvolume',
     )
+    pv_name = models.CharField(
+        max_length=255,
+    )
     description = models.CharField(
         max_length=255,
         blank=True,
@@ -112,6 +115,7 @@ class PhysicalVolume(NetBoxModel):
 
     clone_fields = [
             "partition",
+            "pv_name",
             "description",
         ]
 
@@ -119,7 +123,7 @@ class PhysicalVolume(NetBoxModel):
         return reverse("plugins:netbox_storage:physicalvolume", kwargs={"pk": self.pk})
 
     def __str__(self):
-        return f"PV has XXX Partition"
+        return self.pv_name
 
     class Meta:
         ordering = ("partition", "description")
