@@ -118,9 +118,9 @@ urlpatterns = [
         name="partition_changelog",
         kwargs={"model": Partition},
     ),
-    #path("partition/<int:pk>/physicalvolume/",
-    #     PartitionPhysicalVolumeListView.as_view(),
-    #     name="partition_physicalvolumes"),
+    path("partition/<int:pk>/physicalvolume/",
+         PartitionPhysicalVolumeListView.as_view(),
+         name="partition_physicalvolumes"),
     #
     # PhysicalVolume urls
     #
